==> tencentcloud-sdk-java-3.1.86-sources.jar: com/tencentcloudapi/cloudhsm/v20191112/models/DescribeHSMByVpcIdRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cloudhsm.v20191112.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeHSMByVpcIdRequest extends AbstractModel{

    /**
    * VPC标识符
    */
    @SerializedName("VpcId")
    @Expose
    private String VpcId;

    /**
     * Get VPC标识符 
     * @return VpcId VPC标识符
     */
    public String getVpcId() {
        return this.VpcId;
    }

    /**
     * Set VPC标识符
     * @param VpcId VPC标识符
     */
    public void setVpcId(String VpcId) {
        this.VpcId = VpcId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "VpcId", this.VpcId);

    }
}

==> tencentcloud-sdk-java-3.1.264-sources.jar: com/tencentcloudapi/cloudhsm/v20191112/models/DescribeHSMByVpcIdRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cloudhsm.v20191112.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeHSMByVpcIdRequest extends AbstractModel{

    /**
    * VPC标识符
    */
    @SerializedName("VpcId")
    @Expose
    private String VpcId;

    /**
     * Get VPC标识符 
     * @return VpcId VPC标识符
     */
    public String getVpcId() {
        return this.VpcId;
    }

    /**
     * Set VPC标识符
     * @param VpcId VPC标识符
     */
    public void setVpcId(String VpcId) {
        this.VpcId = VpcId;
    }

    public DescribeHSMByVpcIdRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeHSMByVpcIdRequest(DescribeHSMByVpcIdRequest source) {
        if (source.VpcId != null) {
            this.VpcId = new String(source.VpcId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "VpcId", this.VpcId);

    }
}
